""" Python implementation of Paradox HD7X cameras."""
from .hd77 import ParadoxHD77
